@@ -1,3 +1,4 @@
+from __future__ import print_function
 import argparse
 import os
 import sys
@@ -32,7 +33,7 @@ def frame_iter(video):
 
 for src_path in args.path:
 
-    print 'reading', src_path
+    print('reading', src_path)
 
     basename = os.path.splitext(os.path.basename(src_path))[0]
     dir_name = os.path.join('sandbox', basename)
@@ -54,7 +55,6 @@ for src_path in args.path:
     sum_ /= (fi + 1)
 
     dst_path = os.path.join('sandbox', os.path.basename(src_path) + '-avg.jpeg')
-    print 'writing', (fi + 1), 'frames to', dst_path
-    
-    cv2.imwrite(dst_path, sum_)
+    print('writing', (fi + 1), 'frames to', dst_path)
 
+    cv2.imwrite(dst_path, sum_)
