@@ -1,6 +1,6 @@
 #include "libavutil/avutil.h"
 
-#ifndef PYAV_HAVE_AV_CALLOC
+#if !PYAV_HAVE_AV_CALLOC
 
 #include "libavutil/mem.h"
 
@@ -10,5 +10,10 @@ void *av_calloc(size_t nmemb, size_t size)
         return NULL;
     return av_mallocz(nmemb * size);
 }
-
 #endif
+
+
+#if !PYAV_HAVE_AV_OPT_TYPE_BOOL
+#define AV_OPT_TYPE_BOOL MKBETAG('B','O','O','L')
+#endif
+
