@@ -30,8 +30,10 @@ attribute_visible void R_init_av(DllInfo *dll) {
   av_log_set_callback(my_log_callback);
 
   /* .Call calls */
-  extern SEXP R_convert_audio(SEXP, SEXP);
+  extern SEXP R_audio_fft(SEXP, SEXP, SEXP, SEXP);
+  extern SEXP R_convert_audio(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
   extern SEXP R_encode_video(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+  extern SEXP R_generate_window(SEXP, SEXP);
   extern SEXP R_get_open_handles();
   extern SEXP R_list_codecs();
   extern SEXP R_list_demuxers();
@@ -41,8 +43,10 @@ attribute_visible void R_init_av(DllInfo *dll) {
   extern SEXP R_video_info(SEXP);
 
   static const R_CallMethodDef CallEntries[] = {
-    {"R_convert_audio",    (DL_FUNC) &R_convert_audio,    2},
+    {"R_audio_fft",        (DL_FUNC) &R_audio_fft,        4},
+    {"R_convert_audio",    (DL_FUNC) &R_convert_audio,    7},
     {"R_encode_video",     (DL_FUNC) &R_encode_video,     6},
+    {"R_generate_window",  (DL_FUNC) &R_generate_window,  2},
     {"R_get_open_handles", (DL_FUNC) &R_get_open_handles, 0},
     {"R_list_codecs",      (DL_FUNC) &R_list_codecs,      0},
     {"R_list_demuxers",    (DL_FUNC) &R_list_demuxers,    0},
