@@ -7,7 +7,7 @@ except ImportError:
     from io import BytesIO as StringIO
 
 from .common import *
-from .test_encoding import write_rgb_rotate, assert_rgb_rotate
+from .test_encode import write_rgb_rotate, assert_rgb_rotate
 from av.video.stream import VideoStream
 
 
@@ -63,10 +63,7 @@ class TestPythonIO(TestCase):
         self.assertTrue(writes)
 
         self.assertTrue(buffer_.tell())
-        
+
         # Standard assertions.
         buffer_.seek(0)
         assert_rgb_rotate(self, av.open(buffer_))
-
-
-
